@@ -245,7 +245,7 @@ class MySQL:
         try:
             conn = mysql.connector.connect(user=cred['DE_USER'],
                                             password=cred['DE_USER_PASSWORD'],
-                                            host=host = cred['PROD_MYSQL_READER_HOST'],
+                                            host=cred['PROD_MYSQL_READER_HOST'],
                                             port= cred['PORT_2'],
                                             database='trellDb', charset='utf8mb4')
 
